@@ -336,7 +336,7 @@ string_print_encoded(String *s)
 }
 
 static void
-printtrimmed(char *s)
+printtrimmed(const char *s)
 {
 	char *p, *e;
 
@@ -385,7 +385,7 @@ string_print_trimmed_multi(String *s)
 	}
 }
 
-/* always print absolute URLs (using global baseurl) */
+/* print URL, if it's a relative URL then it uses global baseurl */
 void
 printuri(char *s)
 {
@@ -411,7 +411,7 @@ printuri(char *s)
 	*e = c; /* restore NUL byte to original character */
 }
 
-/* always print absolute URLs (using global baseurl) */
+/* print URL, if it's a relative URL then it uses global baseurl */
 void
 string_print_uri(String *s)
 {
